@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  mod_ssl.h
 **  Global header
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -58,9 +58,9 @@
  * OF THE POSSIBILITY OF SUCH DAMAGE.
  * ====================================================================
  */
-                             /* ``The Apache Group: a collection 
-                                  of talented individuals who are 
-                                  trying to perfect the art of 
+                             /* ``The Apache Group: a collection
+                                  of talented individuals who are
+                                  trying to perfect the art of
                                   never finishing something.''
                                              -- Rob Hartill         */
 #ifndef MOD_SSL_H
@@ -176,7 +176,7 @@
 
 #define SSL_ADD_NONE     (1<<8)
 #define SSL_ADD_ERRNO    (1<<9)
-#define SSL_ADD_SSLEAY   (1<<10)
+#define SSL_ADD_SSLERR   (1<<10)
 #define SSL_NO_TIMESTAMP (1<<11)
 #define SSL_NO_LEVELID   (1<<12)
 #define SSL_NO_NEWLINE   (1<<13)
@@ -192,7 +192,7 @@
 #define SSL_SESSION_CACHE_TIMEOUT  300
 #endif
 
-/* 
+/*
  * Support for file locking: Try to determine whether we should use fcntl() or
  * flock().  Would be better ap_config.h could provide this... :-(
   */
@@ -235,7 +235,7 @@
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/sem.h>
-#endif 
+#endif
 #ifdef WIN32
 #define SSL_CAN_USE_SEM
 #define SSL_HAVE_W32SEM
@@ -261,7 +261,7 @@
 #define ssl_dbm_fetch    sdbm_fetch
 #define ssl_dbm_delete   sdbm_delete
 #define ssl_dbm_firstkey sdbm_firstkey
-#define ssl_dbm_nextkey  sdbm_nextkey 
+#define ssl_dbm_nextkey  sdbm_nextkey
 #define SSL_DBM_FILE_SUFFIX_DIR ".dir"
 #define SSL_DBM_FILE_SUFFIX_PAG ".pag"
 #else
@@ -272,7 +272,7 @@
 #define ssl_dbm_fetch    dbm_fetch
 #define ssl_dbm_delete   dbm_delete
 #define ssl_dbm_firstkey dbm_firstkey
-#define ssl_dbm_nextkey  dbm_nextkey 
+#define ssl_dbm_nextkey  dbm_nextkey
 #if defined(__FreeBSD__) || (defined(DB_LOCK) && defined(DB_SHMEM))
 #define SSL_DBM_FILE_SUFFIX_DIR ".db"
 #define SSL_DBM_FILE_SUFFIX_PAG ".db"
@@ -283,20 +283,36 @@
 #endif
 
 /*
- * Check for SSLeay >= 0.8.0 and enabled Extended API (EAPI)
+ * Check for SSL library version number
  */
-#if SSLEAY_VERSION_NUMBER < 0x0800
-#error "SSLeay versions below 0.8.0 are not supported"
+#ifdef OPENSSL_VERSION_NUMBER
+#define SSL_LIBRARY_VERSION OPENSSL_VERSION_NUMBER
+#define SSL_LIBRARY_NAME    "OpenSSL"
+#else
+#ifdef SSLEAY_VERSION_NUMBER
+#define SSL_LIBRARY_VERSION SSLEAY_VERSION_NUMBER
+#define SSL_LIBRARY_NAME    "SSLeay"
+#else
+#define SSL_LIBRARY_VERSION 0x0000
+#define SSL_LIBRARY_NAME    "OtherSSL"
+#endif
 #endif
 
+/*
+ * Check for SSLeay 0.8.0 and below
+ * and enabled Extended API (EAPI)
+ */
+#if SSL_LIBRARY_VERSION < 0x0800
+#error "SSLeay versions below 0.8.0 are not supported"
+#endif
 #ifndef EAPI
 #error "mod_ssl requires Extended API (EAPI)"
 #endif
 
 /*
- * Correct a typo in SSLeay 
+ * Correct a typo in old SSLeay
  */
-#if SSLEAY_VERSION_NUMBER < 0x900
+#if SSL_LIBRARY_VERSION < 0x900
 #define SSL3_TXT_ADH_DES_192_CBC_SHA SSL3_TXT_ADH_DES_196_CBC_SHA
 #endif
 
@@ -415,20 +431,17 @@ typedef struct {
     ssl_ds_table *tPublicCert;
     ssl_ds_table *tPrivateKey;
 
-    /* 
-     * context data 
+    /*
+     * arbitrary global context data
      */
     struct {
-        conn_rec   *pConn;
-        server_rec *pServ;
-        pool       *pPool;
-        void       *pV1, *pV2, *pV3, *pV4, *pV5, *pV6, *pV7, *pV8, *pV9;
-    } rCtx;           
+        void *pV1, *pV2, *pV3, *pV4, *pV5, *pV6, *pV7, *pV8, *pV9;
+    } rCtx;
 } SSLModConfigRec;
 
 /*
- * Define the mod_ssl per-server configuration structure 
- * (i.e. the configuration for the main server 
+ * Define the mod_ssl per-server configuration structure
+ * (i.e. the configuration for the main server
  *  and all <VirtualHost> contexts)
  */
 typedef struct {
@@ -452,8 +465,8 @@ typedef struct {
 } SSLSrvConfigRec;
 
 /*
- * Define the mod_ssl per-directory configuration structure 
- * (i.e. the local configuration for all <Directory> 
+ * Define the mod_ssl per-directory configuration structure
+ * (i.e. the local configuration for all <Directory>
  *  and .htaccess contexts)
  */
 typedef struct {
@@ -464,7 +477,7 @@ typedef struct {
     OptionType    nOptionsDel;
 } SSLDirConfigRec;
 
-/*  
+/*
  *  function prototypes
  */
 
@@ -497,14 +510,14 @@ const char  *ssl_cmd_SSLRequire(cmd_parms *, SSLDirConfigRec *, char *);
 
 /*  module initialization  */
 void         ssl_init_Module(server_rec *, pool *);
-void         ssl_init_SSLeay(server_rec *);
+void         ssl_init_SSLLibrary(server_rec *);
 void         ssl_init_GetCertAndKey(server_rec *, pool *, SSLSrvConfigRec *);
 STACK       *ssl_init_FindCAList(server_rec *, pool *, char *, char *);
 void         ssl_init_Child(server_rec *, pool *);
 
 /*  Apache API hooks  */
 void         ssl_hook_AddModule(module *);
-char        *ssl_hook_RewriteCommand(cmd_parms *, const char *);
+char        *ssl_hook_RewriteCommand(cmd_parms *, void *config, const char *);
 void         ssl_hook_NewConnection(conn_rec *);
 void         ssl_hook_CloseConnection(void *);
 int          ssl_hook_Auth(request_rec *);
@@ -514,7 +527,6 @@ int          ssl_hook_ReadReq(request_rec *);
 int          ssl_hook_Handler(request_rec *);
 
 /*  SSLeay callbacks */
-int          ssl_callback_PassPhrase(char *, int, int);
 RSA         *ssl_callback_TmpRSA(SSL *, int);
 int          ssl_callback_SSLVerify(int, X509_STORE_CTX *);
 int          ssl_callback_NewSessionCacheEntry(SSL *, SSL_SESSION *);
@@ -524,16 +536,16 @@ void         ssl_callback_LogTracingState(SSL *, int, int);
 
 /*  Session Cache Support  */
 void         ssl_scache_init(server_rec *, pool *);
-void         ssl_scache_store(SSL_SESSION *, int);
-SSL_SESSION *ssl_scache_retrieve(UCHAR *, int);
-void         ssl_scache_remove(SSL_SESSION *);
-void         ssl_scache_expire(void);
+void         ssl_scache_store(server_rec *, SSL_SESSION *, int);
+SSL_SESSION *ssl_scache_retrieve(server_rec *, UCHAR *, int);
+void         ssl_scache_remove(server_rec *, SSL_SESSION *);
+void         ssl_scache_expire(server_rec *);
 char        *ssl_scache_id2sz(UCHAR *, int);
 void         ssl_scache_dbm_init(server_rec *, pool *);
-void         ssl_scache_dbm_store(SessionCacheInfo *);
-void         ssl_scache_dbm_retrieve(SessionCacheInfo *);
-void         ssl_scache_dbm_remove(SessionCacheInfo *);
-void         ssl_scache_dbm_expire(void);
+void         ssl_scache_dbm_store(server_rec *, SessionCacheInfo *);
+void         ssl_scache_dbm_retrieve(server_rec *, SessionCacheInfo *);
+void         ssl_scache_dbm_remove(server_rec *, SessionCacheInfo *);
+void         ssl_scache_dbm_expire(server_rec *);
 
 /*  Pass Phrase Support  */
 void         ssl_pphrase_Handle(server_rec *, pool *);
@@ -593,7 +605,7 @@ void         ssl_compat_variables(request_rec *);
 
 /*  Utility Functions  */
 void         ssl_util_strupper(char *);
-void         ssl_util_uuencode(char *, const char *, BOOL); 
+void         ssl_util_uuencode(char *, const char *, BOOL);
 void         ssl_util_uuencode_binary(unsigned char *, const unsigned char *, int, BOOL);
 FILE        *ssl_util_ppopen(server_rec *, pool *, char *);
 int          ssl_util_ppopen_child(void *, child_info *);
