@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_config.c
 **  Apache Configuration Directives
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -59,7 +59,7 @@
  * ====================================================================
  */
 
-                                      /* ``Damned if you do, 
+                                      /* ``Damned if you do,
                                            damned if you don't.''
                                                -- Unknown        */
 #include "mod_ssl.h"
@@ -96,7 +96,7 @@ void ssl_config_global_create(void)
 
     mc = ap_ctx_get(ap_global_ctx, "ssl_module");
     if (mc == NULL) {
-        /* 
+        /*
          * allocate an own subpool which survives server restarts
          */
         pPool = ap_make_sub_pool(NULL);
@@ -118,10 +118,6 @@ void ssl_config_global_create(void)
         mc->tPrivateKey            = ssl_ds_table_make(pPool, sizeof(RSA *));
         mc->tPublicCert            = ssl_ds_table_make(pPool, sizeof(X509 *));
 
-        mc->rCtx.pConn             = NULL;
-        mc->rCtx.pServ             = NULL;
-        mc->rCtx.pPool             = NULL;
-
         /*
          * And push it into Apache's global context
          */
@@ -143,9 +139,9 @@ void ssl_config_global_create(void)
 void *ssl_config_server_create(pool *p, server_rec *s)
 {
     SSLSrvConfigRec *sc;
-    
+
     ssl_config_global_create();
-    
+
     sc = ap_palloc(p, sizeof(SSLSrvConfigRec));
     sc->bEnabled               = UNSET;
     sc->szCertificateFile      = SSL_CERTIFCATE_FILE;
@@ -223,7 +219,7 @@ void *ssl_config_perdir_merge(pool *p, void *basev, void *addv)
 {
     SSLDirConfigRec *base = (SSLDirConfigRec *)basev;
     SSLDirConfigRec *add  = (SSLDirConfigRec *)addv;
-    SSLDirConfigRec *new  = (SSLDirConfigRec *)ap_palloc(p, 
+    SSLDirConfigRec *new  = (SSLDirConfigRec *)ap_palloc(p,
                                                sizeof(SSLDirConfigRec));
 
     cfgMerge(bSSLRequired, FALSE);
@@ -247,7 +243,7 @@ void *ssl_config_perdir_merge(pool *p, void *basev, void *addv)
  * Directive Rewriting
  */
 
-char *ssl_hook_RewriteCommand(cmd_parms *cmd, const char *cmd_line)
+char *ssl_hook_RewriteCommand(cmd_parms *cmd, void *config, const char *cmd_line)
 {
 #ifdef SSL_COMPAT
     return ssl_compat_directive(cmd->server, cmd->pool, cmd_line);
@@ -306,7 +302,7 @@ const char *ssl_cmd_SSLPassPhraseDialog(
             return ap_pstrcat(cmd->pool, "SSLPassPhraseDialog: file '",
                               sc->szPassPhraseDialogPath, "' not exists", NULL);
     }
-    else 
+    else
         return "SSLPassPhraseDialog: Invalid argument";
     return NULL;
 }
@@ -504,7 +500,7 @@ const char *ssl_cmd_SSLOptions(
             dc->nOptions = SSL_OPT_NONE;
             first = FALSE;
         }
-        
+
         if (strcEQ(w, "CompatEnvVars"))
             opt = SSL_OPT_COMPATENVVARS;
         else if (strcEQ(w, "ExportCertData"))
@@ -545,7 +541,7 @@ const char *ssl_cmd_SSLRequire(
 {
     ssl_expr *mpExpr;
     SSLRequirement *pReqRec;
-    
+
     if ((mpExpr = ssl_expr_comp(cmd->pool, cpExpr)) == NULL)
         return ap_pstrcat(cmd->pool, "SSLRequire: ", ssl_expr_get_error(), NULL);
     pReqRec = ap_push_array(dc->aRequirement);
