@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_init.c
 **  Initialization of Servers
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -67,7 +67,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -128,12 +128,9 @@ void ssl_init_Module(server_rec *s, pool *p)
 
     mc->nInitCount++;
 
-    mc->rCtx.pServ = s;
-    mc->rCtx.pPool = p;
-
-    /* 
+    /*
      *  try to fix the configuration and open the dedicated SSL
-     *  logfile as early as possible 
+     *  logfile as early as possible
      */
     for (s2 = s; s2 != NULL; s2 = s2->next) {
         sc = mySrvConfig(s2);
@@ -162,9 +159,9 @@ void ssl_init_Module(server_rec *s, pool *p)
         ssl_log(s, SSL_LOG_INFO, "Init: %d%s restart round (already detached)",
                 mc->nInitCount-2, (mc->nInitCount-2) == 1 ? "st" : "nd");
 
-    /*  
-     *  The initialization phase inside the Apache API is totally bogus. 
-     *  We actually have three non-trivial problems: 
+    /*
+     *  The initialization phase inside the Apache API is totally bogus.
+     *  We actually have three non-trivial problems:
      *
      *  1. Under Unix the API does a 2-round initialization of modules while
      *     under Win32 it doesn't. This means we have to make sure that at
@@ -189,20 +186,19 @@ void ssl_init_Module(server_rec *s, pool *p)
      *              (-DSHARED_MODULE) (-DWIN32)
      *  ----------- ----------------- --------- -----------------------------------
      *  -           load module       -         -
-     *  init        init              init      SSLeay init, Pass Phrase Dialog
+     *  init        init              init      SSL library init, Pass Phrase Dialog
      *  detach      detach            -         -
      *  -           reload module     -         -
-     *  init        init              -         SSLeay init, mod_ssl init
+     *  init        init              -         SSL library init, mod_ssl init
      *
      *  Ok, now try to solve this totally ugly situation...
      */
 
 #ifdef SHARED_MODULE
-    ssl_init_SSLeay(s);
+    ssl_init_SSLLibrary(s);
 #else
-    if (mc->nInitCount <= 2) {
-        ssl_init_SSLeay(s);
-    }
+    if (mc->nInitCount <= 2)
+        ssl_init_SSLLibrary(s);
 #endif
     if (mc->nInitCount == 1) {
         ssl_pphrase_Handle(s, p);
@@ -216,7 +212,7 @@ void ssl_init_Module(server_rec *s, pool *p)
      * But we can operate without it, of course.
      */
     if (mc->nSessionCacheMode == SSL_SCMODE_UNSET) {
-        ssl_log(s, SSL_LOG_WARN, 
+        ssl_log(s, SSL_LOG_WARN,
                 "Init: Session Cache is not configured [hint: SSLSessionCache]");
         mc->nSessionCacheMode = SSL_SCMODE_NONE;
     }
@@ -232,7 +228,7 @@ void ssl_init_Module(server_rec *s, pool *p)
      */
     if (mc->pRSATmpKey == NULL) {
         ssl_log(s, SSL_LOG_INFO, "Init: Generating temporary (512 bit) RSA private key");
-#if SSLEAY_VERSION_NUMBER >= 0x0900
+#if (SSL_LIBRARY_VERSION >= 0x0900)
         mc->pRSATmpKey = RSA_generate_key(512, RSA_F4, NULL, NULL);
 #else
         mc->pRSATmpKey = RSA_generate_key(512, RSA_F4, NULL);
@@ -251,7 +247,7 @@ void ssl_init_Module(server_rec *s, pool *p)
         sc = mySrvConfig(s);
 
         if (sc->bEnabled)
-            ssl_log(s, SSL_LOG_INFO, 
+            ssl_log(s, SSL_LOG_INFO,
                     "Init: Configuring server %s:%d for SSL protocol",
                     s->server_hostname, s->port);
 
@@ -265,13 +261,13 @@ void ssl_init_Module(server_rec *s, pool *p)
 
         /* Give a warning when HTTPS is configured for HTTP port */
         if (s->port == DEFAULT_HTTP_PORT)
-            ssl_log(s, SSL_LOG_WARN, 
+            ssl_log(s, SSL_LOG_WARN,
                     "Init: You configured HTTPS on the standard HTTP(%d) port!",
                     DEFAULT_HTTP_PORT);
         if (!s->port)
             s->port = DEFAULT_HTTPS_PORT;
 
-        /* 
+        /*
          * Now check for important parameters and the
          * possibility that the user forgot to set them.
          */
@@ -296,8 +292,8 @@ void ssl_init_Module(server_rec *s, pool *p)
     }
 
     /*
-     *  Announce mod_ssl and SSLeay in HTTP Server field
-     *  as ``mod_ssl/X.X.X SSLeay/X.X.X''
+     *  Announce mod_ssl and SSL library in HTTP Server field
+     *  as ``mod_ssl/X.X.X OpenSSL/X.X.X''
      */
     if ((cp = ssl_var_lookup(p, NULL, NULL, NULL, "SSL_VERSION_PRODUCT")) != NULL && cp[0] != NUL)
         ap_add_version_component(cp);
@@ -308,11 +304,11 @@ void ssl_init_Module(server_rec *s, pool *p)
 }
 
 /*
- *  Initialize SSLeay (also already needed for the pass phrase dialog)
+ *  Initialize SSL library (also already needed for the pass phrase dialog)
  */
-void ssl_init_SSLeay(server_rec *s)
+void ssl_init_SSLLibrary(server_rec *s)
 {
-    ssl_log(s, SSL_LOG_INFO, "Init: Initializing SSLeay library");
+    ssl_log(s, SSL_LOG_INFO, "Init: Initializing %s library", SSL_LIBRARY_NAME);
 #ifdef WIN32
     CRYPTO_malloc_init();
 #endif
@@ -332,62 +328,53 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
     char *cpServerName;
     RSA **ppRSA;
     X509 **ppX509;
+    SSL_CTX *ctx;
 
     cpServerName = ap_psprintf(p, "%s:%d", s->server_hostname, s->port);
 
-    /*  
+    /*
      *  Check for problematic re-initializations
      */
     if (sc->px509Certificate) {
-        ssl_log(s, SSL_LOG_ERROR, 
+        ssl_log(s, SSL_LOG_ERROR,
                 "Init: (%s) Illegal attempt to re-initialise SSL for server",
                 cpServerName);
         ssl_die();
     }
 
     /*
-     *  Calculate SSLeay verify type
+     *  Create new SSL context
+     */
+    ssl_log(s, SSL_LOG_TRACE,
+            "Init: (%s) Creating new SSL context", cpServerName);
+    ctx = SSL_CTX_new(SSLv23_server_method());
+    SSL_CTX_set_app_data(ctx, s);
+    sc->pSSLCtx = ctx;
+
+    /*
+     *  Configure callback for SSL context
      */
     nVerify = SSL_VERIFY_NONE;
-    switch (sc->nVerifyClient) {
-        case SSL_CVERIFY_REQUIRE:
-            nVerify |= SSL_VERIFY_PEER|SSL_VERIFY_FAIL_IF_NO_PEER_CERT;
-            break;
-        case SSL_CVERIFY_OPTIONAL:
-        case SSL_CVERIFY_OPTIONAL_NO_CA:
-            nVerify |= SSL_VERIFY_PEER;
-            break;
-        default:
-            break;
-    }
+    if (sc->nVerifyClient == SSL_CVERIFY_REQUIRE)
+        nVerify |= SSL_VERIFY_PEER|SSL_VERIFY_FAIL_IF_NO_PEER_CERT;
+    if (   (sc->nVerifyClient == SSL_CVERIFY_OPTIONAL)
+        || (sc->nVerifyClient == SSL_CVERIFY_OPTIONAL_NO_CA) )
+        nVerify |= SSL_VERIFY_PEER;
+    SSL_CTX_set_verify(ctx, nVerify,  ssl_callback_SSLVerify);
+    SSL_CTX_sess_set_new_cb(ctx,      ssl_callback_NewSessionCacheEntry);
+    SSL_CTX_sess_set_get_cb(ctx,      ssl_callback_GetSessionCacheEntry);
+    SSL_CTX_sess_set_remove_cb(ctx,   ssl_callback_DelSessionCacheEntry);
+    SSL_CTX_set_tmp_rsa_callback(ctx, ssl_callback_TmpRSA);
+    SSL_CTX_set_info_callback(ctx,    ssl_callback_LogTracingState);
 
     /*
-     *  Create new SSL context and configure callbacks
+     *  Configure required SSL Ciphers
      */
-    ssl_log(s, SSL_LOG_TRACE, 
-            "Init: (%s) Creating new SSL context", cpServerName);
-    sc->pSSLCtx = SSL_CTX_new(SSLv23_server_method());
-    SSL_CTX_set_verify(sc->pSSLCtx, nVerify, 
-                 ssl_callback_SSLVerify);
-    SSL_CTX_sess_set_new_cb(sc->pSSLCtx, 
-                 ssl_callback_NewSessionCacheEntry);
-    SSL_CTX_sess_set_get_cb(sc->pSSLCtx, 
-                 ssl_callback_GetSessionCacheEntry);
-    SSL_CTX_sess_set_remove_cb(sc->pSSLCtx, 
-                 ssl_callback_DelSessionCacheEntry);
-    SSL_CTX_set_tmp_rsa_callback(sc->pSSLCtx, 
-                 ssl_callback_TmpRSA);
-    SSL_CTX_set_info_callback(sc->pSSLCtx, 
-                 ssl_callback_LogTracingState);
-
-    /*
-     *  Configure required SSL Ciphers 
-     */
-    ssl_log(s, SSL_LOG_TRACE, 
+    ssl_log(s, SSL_LOG_TRACE,
             "Init: (%s) Configuring permitted SSL ciphers", cpServerName);
     if (sc->szCipherSuite != NULL) {
         if (!SSL_CTX_set_cipher_list(sc->pSSLCtx, sc->szCipherSuite)) {
-            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: (%s) Unable to configure permitted SSL ciphers",
                     cpServerName);
             ssl_die();
@@ -399,16 +386,16 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
      */
     if (sc->szCACertificateFile != NULL || sc->szCACertificatePath != NULL) {
         STACK *skCAList;
-        ssl_log(s, SSL_LOG_TRACE, 
+        ssl_log(s, SSL_LOG_TRACE,
                 "Init: (%s) Configuring client authentication", cpServerName);
-        if (!SSL_CTX_load_verify_locations(sc->pSSLCtx, 
+        if (!SSL_CTX_load_verify_locations(sc->pSSLCtx,
                 sc->szCACertificateFile, sc->szCACertificatePath)) {
-            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: (%s) Unable to configure verify locations "
                     "for client authentication", cpServerName);
             ssl_die();
         }
-        if ((skCAList = ssl_init_FindCAList(s, p, sc->szCACertificateFile, 
+        if ((skCAList = ssl_init_FindCAList(s, p, sc->szCACertificateFile,
                                             sc->szCACertificatePath)) == NULL) {
             ssl_log(s, SSL_LOG_ERROR,
                     "Init: (%s) Unable to determine list of available "
@@ -421,23 +408,23 @@ void ssl_init_GetCertAndKey(server_rec *s, pool *p, SSLSrvConfigRec *sc)
     /*
      *  Configure server certificate
      */
-    ssl_log(s, SSL_LOG_TRACE, 
+    ssl_log(s, SSL_LOG_TRACE,
             "Init: (%s) Configuring server certificate", cpServerName);
-    if ((ppX509 = (X509 **)ssl_ds_table_get(mc->tPublicCert, 
+    if ((ppX509 = (X509 **)ssl_ds_table_get(mc->tPublicCert,
                                             cpServerName)) == NULL) {
-        ssl_log(s, SSL_LOG_ERROR, 
+        ssl_log(s, SSL_LOG_ERROR,
                 "Init: (%s) Ops, can't find server certificate?!", cpServerName);
         ssl_die();
     }
     sc->px509Certificate = *ppX509;
 
     /*
-     *  Configure server private key 
+     *  Configure server private key
      */
-    ssl_log(s, SSL_LOG_TRACE, 
+    ssl_log(s, SSL_LOG_TRACE,
             "Init: (%s) Configuring server private key", cpServerName);
     if ((ppRSA = (RSA **)ssl_ds_table_get(mc->tPrivateKey, cpServerName)) == NULL) {
-        ssl_log(s, SSL_LOG_ERROR, 
+        ssl_log(s, SSL_LOG_ERROR,
                 "Init: (%s) Ops, can't find server private key?!", cpServerName);
         ssl_die();
     }
