@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_io.c
 **  I/O Functions
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -59,7 +59,7 @@
  * ====================================================================
  */
                              /* ``MY HACK: This universe.
-                                  Just one little problem: 
+                                  Just one little problem:
                                   core keeps dumping.''
                                             -- Unknown    */
 #include "mod_ssl.h"
@@ -109,8 +109,8 @@ static int ssl_io_hook_read(BUFF *fb, char *buf, int len)
         rc = SSL_read(ssl, buf, len);
         if (rc < 0)
             rc = -1;
-        /* 
-         * Simulate an EINTR in case SSLeay wants to read more.  
+        /*
+         * Simulate an EINTR in case SSLeay wants to read more.
          * (This is usually the case when the client forces an SSL
          * renegotation which is handled implicitly by SSLeay.)
          */
@@ -131,8 +131,8 @@ static int ssl_io_hook_write(BUFF *fb, char *buf, int len)
         rc = SSL_write(ssl, buf, len);
         if (rc < 0)
             rc = -1;
-        /* 
-         * Simulate an EINTR in case SSLeay wants to write more.  
+        /*
+         * Simulate an EINTR in case SSLeay wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
@@ -155,13 +155,13 @@ static int ssl_io_hook_writev(BUFF *fb, const struct iovec *iov, int iovcnt)
         rc = SSL_writev(ssl, iov, iovcnt);
         if (rc < 0)
             rc = -1;
-        /* 
-         * Simulate an EINTR in case SSLeay wants to write more.  
+        /*
+         * Simulate an EINTR in case SSLeay wants to write more.
          */
         if (rc < 0 && SSL_get_error(ssl, rc) == SSL_ERROR_WANT_WRITE)
             errno = EINTR;
     }
-    else 
+    else
         rc = writev(fb->fd, iov, iovcnt);
     return rc;
 }
@@ -223,7 +223,7 @@ static int SSL_sendwithtimeout(BUFF *fb, const char *buf, int len)
     SSL *ssl;
 
     ssl = ap_ctx_get(fb->ctx, "ssl");
-    
+
     if (!(tv.tv_sec = ap_check_alarm()))
         return (SSL_write(ssl, (char*)buf, len));
 
@@ -282,7 +282,7 @@ static int SSL_recvwithtimeout(BUFF *fb, char *buf, int len)
     SSL *ssl;
 
     ssl = ap_ctx_get(fb->ctx, "ssl");
-    
+
     if (!(tv.tv_sec = ap_check_alarm()))
         return (SSL_read(ssl, buf, len));
 
@@ -359,14 +359,14 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
     char tmp[64];
     int i, j, rows, trunc;
     unsigned char ch;
-    
+
     trunc = 0;
-    for(; (len > 0) && ((s[len-1] == ' ') || (s[len-1] == '\0')); len--) 
+    for(; (len > 0) && ((s[len-1] == ' ') || (s[len-1] == '\0')); len--)
         trunc++;
     rows = (len / DUMP_WIDTH);
     if ((rows * DUMP_WIDTH) < len)
         rows++;
-    ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID, 
+    ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID,
             "+-------------------------------------------------------------------------+");
     for(i = 0 ; i< rows; i++) {
         ap_snprintf(tmp, sizeof(tmp), "| %04x: ", i * DUMP_WIDTH);
@@ -394,9 +394,9 @@ static void ssl_io_data_dump(server_rec *srvr, char *s, long len)
         ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID, "%s", buf);
     }
     if (trunc > 0)
-        ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID, 
+        ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID,
                 "%04x - <SPACES/NULS>", len + trunc);
-    ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID, 
+    ssl_log(srvr, SSL_LOG_DEBUG|SSL_NO_TIMESTAMP|SSL_NO_LEVELID,
             "+-------------------------------------------------------------------------+");
     return;
 }
@@ -414,15 +414,15 @@ long ssl_io_data_cb(BIO *bio, int cmd, char *argp, int argi, long argl, long len
     s = c->server;
 
     if (cmd == (BIO_CB_READ|BIO_CB_RETURN)) {
-        ssl_log(s, SSL_LOG_DEBUG, 
-                "SSLeay: read %ld/%d bytes from BIO#%08X [mem: %08lX] (BIO dump follows)",
-                len, argi, bio, argp);
+        ssl_log(s, SSL_LOG_DEBUG,
+                "%s: read %ld/%d bytes from BIO#%08X [mem: %08lX] (BIO dump follows)",
+                SSL_LIBRARY_NAME, len, argi, bio, argp);
         ssl_io_data_dump(s, argp, len);
     }
     else if (cmd == (BIO_CB_WRITE|BIO_CB_RETURN)) {
-        ssl_log(s, SSL_LOG_DEBUG, 
-                "SSLeay: write %ld/%d bytes to BIO#%08X [mem: %08lX] (BIO dump follows)",
-                len, argi, bio, argp);
+        ssl_log(s, SSL_LOG_DEBUG,
+                "%s: write %ld/%d bytes to BIO#%08X [mem: %08lX] (BIO dump follows)",
+                SSL_LIBRARY_NAME, len, argi, bio, argp);
         ssl_io_data_dump(s, argp, len);
     }
     return len;
