@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_kernel.c
 **  The SSL engine kernel
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -67,7 +67,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -127,7 +127,6 @@
  */
 void ssl_hook_NewConnection(conn_rec *conn)
 {
-    SSLModConfigRec *mc = myModConfig();
     server_rec *srvr;
     BUFF *fb;
     SSLSrvConfigRec *sc;
@@ -148,7 +147,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
     ap_ctx_set(fb->ctx, "ssl", NULL);
 
     /*
-     * Immediately stop processing if SSL 
+     * Immediately stop processing if SSL
      * is disabled for this connection
      */
     if (sc == NULL || !sc->bEnabled)
@@ -161,13 +160,6 @@ void ssl_hook_NewConnection(conn_rec *conn)
     ssl_log(srvr, SSL_LOG_INFO, "Connection to child %d established (server %s:%d)",
             conn->child_num, srvr->server_hostname, srvr->port);
 
-    /*
-     * Globally remember some connection context
-     */
-    mc->rCtx.pConn = conn;
-    mc->rCtx.pServ = conn->server;
-    mc->rCtx.pPool = conn->pool;
-
     /*
      * Create a new SSL connection with the configured server SSL context and
      * attach this to the socket. Additionally we register this attachment
@@ -177,11 +169,11 @@ void ssl_hook_NewConnection(conn_rec *conn)
     SSL_set_app_data(ssl, conn);
     SSL_set_fd(ssl, fb->fd);
     ap_ctx_set(fb->ctx, "ssl", ssl);
-    ap_register_cleanup(conn->pool, (void *)conn, 
+    ap_register_cleanup(conn->pool, (void *)conn,
                         ssl_hook_CloseConnection, ssl_hook_CloseConnection);
 
     /*
-     * Configure SSLeay BIO Data Logging 
+     * Configure SSLeay BIO Data Logging
      */
     if (sc->nLogLevel >= SSL_LOG_DEBUG) {
         BIO_set_callback(SSL_get_rbio(ssl), ssl_io_data_cb);
@@ -189,12 +181,12 @@ void ssl_hook_NewConnection(conn_rec *conn)
     }
 
     /*
-     * Configure the server certificate and private key 
+     * Configure the server certificate and private key
      * which should be used for this connection.
      */
     if (sc->szCertificateFile != NULL) {
         if (SSL_use_certificate(ssl, sc->px509Certificate) <= 0) {
-            ssl_log(conn->server, SSL_LOG_ERROR|SSL_ADD_SSLEAY,
+            ssl_log(conn->server, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Unable to configure server certificate for connection");
             SSL_free(ssl);
             ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -202,7 +194,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
             return;
         }
         if (SSL_use_RSAPrivateKey(ssl, sc->prsaKey) <= 0) {
-            ssl_log(conn->server, SSL_LOG_ERROR|SSL_ADD_SSLEAY,
+            ssl_log(conn->server, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Unable to configure server private key for connection");
             SSL_free(ssl);
             ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -229,14 +221,14 @@ void ssl_hook_NewConnection(conn_rec *conn)
                  */
                 ssl_log(srvr, SSL_LOG_INFO,
                         "SSL handshake stopped: connection was closed");
-                SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN); 
+                SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
                 while (!SSL_shutdown(ssl));
                 SSL_free(ssl);
                 ap_ctx_set(fb->ctx, "ssl", NULL);
                 fb->flags |= B_EOF|B_EOUT;
                 return;
             }
-#if (SSLEAY_VERSION_NUMBER >= 0x0900)
+#if (SSL_LIBRARY_VERSION >= 0x0900)
             else if (ERR_GET_REASON(ERR_peek_error()) == SSL_R_HTTP_REQUEST) {
                 /*
                  * The case where SSLeay has recognized a HTTP request:
@@ -254,26 +246,26 @@ void ssl_hook_NewConnection(conn_rec *conn)
                 int rv;
 
                 /* log the situation */
-                ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+                ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                         "SSL handshake failed: HTTP spoken on HTTPS port; "
                         "trying to send HTML error page");
 
                 /* first: skip the remaining bytes of the request line */
                 do {
                     do {
-                        rv = read(fb->fd, ca, 1); 
+                        rv = read(fb->fd, ca, 1);
                     } while (rv == -1 && errno == EINTR);
                 } while (rv > 0 && ca[0] != '\012' /*LF*/);
 
                 /* second: fake the request line */
                 fb->inbase = ap_palloc(fb->pool, fb->bufsiz);
-                ap_cpystrn((char *)fb->inbase, "GET /mod_ssl:error:HTTP-request HTTP/1.0\r\n", 
+                ap_cpystrn((char *)fb->inbase, "GET /mod_ssl:error:HTTP-request HTTP/1.0\r\n",
                            fb->bufsiz);
                 fb->inptr = fb->inbase;
                 fb->incnt = strlen((char *)fb->inptr);
 
                 /* third: kick away the SSL stuff */
-                SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN); 
+                SSL_set_shutdown(ssl, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
                 while (!SSL_shutdown(ssl));
                 SSL_free(ssl);
                 ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -286,16 +278,16 @@ void ssl_hook_NewConnection(conn_rec *conn)
                 /*
                  * Ok, anything else is a fatal error
                  */
-                ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+                ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                         "SSL handshake failed");
-                /* 
+                /*
                  * try to gracefully shutdown the connection:
                  * - send an own shutdown message (be gracefully)
                  * - don't wait for peer's shutdown message (deadloop)
                  * - kick away the SSL stuff immediately
                  * - block the socket, so Apache cannot operate any more
                  */
-                SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN); 
+                SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
                 while (!SSL_shutdown(ssl));
                 SSL_free(ssl);
                 ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -308,9 +300,9 @@ void ssl_hook_NewConnection(conn_rec *conn)
          * Check for failed client authentication
          */
         if ((cp = (char *)ap_ctx_get(fb->ctx, "ssl:verifyerror")) != NULL) {
-            ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+            ssl_log(srvr, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "SSL client authentication failed: %s", cp);
-            SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN); 
+            SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
             while (!SSL_shutdown(ssl));
             SSL_free(ssl);
             ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -319,7 +311,7 @@ void ssl_hook_NewConnection(conn_rec *conn)
         }
 
         /*
-         * Remember the peer certificate when 
+         * Remember the peer certificate when
          * client authentication was done
          */
         if (sc->nVerifyClient != SSL_CVERIFY_NONE) {
@@ -338,9 +330,9 @@ void ssl_hook_NewConnection(conn_rec *conn)
          */
         if (   sc->nVerifyClient == SSL_CVERIFY_REQUIRE
             && ap_ctx_get(fb->ctx, "ssl:clientdn") == NULL) {
-            ssl_log(srvr, SSL_LOG_ERROR, 
+            ssl_log(srvr, SSL_LOG_ERROR,
                     "No acceptable peer certificate available");
-            SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN); 
+            SSL_set_shutdown(ssl, SSL_RECEIVED_SHUTDOWN);
             while (!SSL_shutdown(ssl));
             SSL_free(ssl);
             ap_ctx_set(fb->ctx, "ssl", NULL);
@@ -349,8 +341,8 @@ void ssl_hook_NewConnection(conn_rec *conn)
         }
     }
 
-    /* 
-     * Improve I/O throughput by using 
+    /*
+     * Improve I/O throughput by using
      * SSLeay's read-ahead functionality
      * (don't used under Win32, because
      * there we use select())
@@ -367,7 +359,6 @@ void ssl_hook_NewConnection(conn_rec *conn)
  */
 void ssl_hook_CloseConnection(void *_conn)
 {
-    SSLModConfigRec *mc = myModConfig();
     conn_rec *conn = _conn;
     SSL *ssl;
 
@@ -382,13 +373,6 @@ void ssl_hook_CloseConnection(void *_conn)
         ap_ctx_set(conn->client->ctx, "ssl", NULL);
     }
 
-    /* 
-     * Delete connection context
-     */
-    mc->rCtx.pConn = NULL;
-    mc->rCtx.pServ = NULL;
-    mc->rCtx.pPool = NULL;
-
     /*
      * And finally log the connection close
      */
@@ -403,7 +387,7 @@ void ssl_hook_CloseConnection(void *_conn)
  */
 int ssl_hook_ReadReq(request_rec *r)
 {
-    if (strEQn(r->uri, "/mod_ssl:", 9)) 
+    if (strEQn(r->uri, "/mod_ssl:", 9))
         r->handler = "mod_ssl:content-handler";
     if (ap_ctx_get(r->connection->client->ctx, "ssl") != NULL) {
         ap_ctx_set(r->ctx, "ap::http::method",  "https");
@@ -439,7 +423,7 @@ int ssl_hook_Handler(request_rec *r)
         ap_table_setn(r->notes, "error-notes", ap_psprintf(r->pool,
                       "You're speaking plain HTTP to an SSL-enabled server.<BR>\n"
                       "Instead use HTTPS protocol to access this server, please.<BR>\n"
-                      "<BLOCKQUOTE>Hint: <A HREF=\"%s\">%s</A></BLOCKQUOTE>", 
+                      "<BLOCKQUOTE>Hint: <A HREF=\"%s\">%s</A></BLOCKQUOTE>",
                       thisurl, thisurl));
         r->status_line = "500 SSL Engine Error";
     }
@@ -474,7 +458,7 @@ int ssl_hook_Auth(request_rec *r)
         return DECLINED;
     if ((clientdn = (char *)ap_ctx_get(r->connection->client->ctx, "ssl:clientdn")) == NULL)
         return DECLINED;
-    
+
     /*
      * Fake a password - which one would be immaterial, as, it seems, an empty
      * password in the users file would match ALL incoming passwords, if only
@@ -516,8 +500,8 @@ int ssl_hook_Access(request_rec *r)
         return FORBIDDEN;
     }
 
-    /* 
-     * Check to see if SSL protocol is on 
+    /*
+     * Check to see if SSL protocol is on
      */
     if (!sc->bEnabled)
         return DECLINED;
@@ -537,7 +521,7 @@ int ssl_hook_Access(request_rec *r)
             return FORBIDDEN;
         }
         if (ok != 1) {
-            ssl_log(r->server, SSL_LOG_INFO, 
+            ssl_log(r->server, SSL_LOG_INFO,
                     "Access to %s denied for %s (requirement expression not fulfilled)",
                     r->filename, r->connection->remote_ip);
             ssl_log(r->server, SSL_LOG_INFO,
@@ -622,7 +606,7 @@ int ssl_hook_Fixup(request_rec *r)
     char *val;
     int i;
 
-    /* 
+    /*
      * Check to see if SSL is on
      */
     if (!sc->bEnabled)
@@ -667,20 +651,6 @@ int ssl_hook_Fixup(request_rec *r)
 */
 
 /*
- * Just a stub in case SSLeay again wants a pass phrase
- */
-int ssl_callback_PassPhrase(char *buf, int bufsize, int dummy)
-{
-    SSLModConfigRec *mc = myModConfig();
-
-    ssl_log(mc->rCtx.pServ, SSL_LOG_ERROR,
-            "Ops, an unexpected request from SSLeay for a phrase phrase occured.");
-    ssl_log(mc->rCtx.pServ, SSL_LOG_INFO,
-            "You should perform a hard server restart because the keyfiles seems to have changed.");
-    return (-1);
-}
-
-/* 
  * Handle out the already generated RSA key...
  */
 RSA *ssl_callback_TmpRSA(SSL *pSSL, int nExport)
@@ -696,13 +666,23 @@ RSA *ssl_callback_TmpRSA(SSL *pSSL, int nExport)
  */
 int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
 {
-    SSLModConfigRec *mc = myModConfig();
+    SSL *ssl;
+    conn_rec *conn;
+    server_rec *s;
+    SSLSrvConfigRec *sc;
     X509 *xs;
     int errnum;
     int errdepth;
-    char *cp, *cp2;
+    char *cp;
+    char *cp2;
 
-    SSLSrvConfigRec *sc = mySrvConfig(mc->rCtx.pConn->server);
+    /*
+     * Get Apache context back through SSLeay context
+     */
+    ssl  = (SSL *)X509_STORE_CTX_get_app_data(ctx);
+    conn = (conn_rec *)SSL_get_app_data(ssl);
+    s    = conn->server;
+    sc   = mySrvConfig(s);
 
     /*
      * Get verify ingredients
@@ -711,14 +691,14 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
     errnum   = X509_STORE_CTX_get_error(ctx);
     errdepth = X509_STORE_CTX_get_error_depth(ctx);
 
-    /* 
+    /*
      * Log verification information
      */
     cp  = X509_NAME_oneline(X509_get_subject_name(xs), NULL, 0);
     cp2 = X509_NAME_oneline(X509_get_issuer_name(xs),  NULL, 0);
-    ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE,
-            "Certificate Verification: depth: %d, subject: %s, issuer: %s", 
-            errdepth, cp != NULL ? cp : "-unknown-", 
+    ssl_log(s, SSL_LOG_TRACE,
+            "Certificate Verification: depth: %d, subject: %s, issuer: %s",
+            errdepth, cp != NULL ? cp : "-unknown-",
             cp2 != NULL ? cp2 : "-unknown");
     free(cp);
     free(cp2);
@@ -728,10 +708,10 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
      */
     if (   (   errnum == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT
             || errnum == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN
-            || errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY 
+            || errnum == X509_V_ERR_UNABLE_TO_GET_ISSUER_CERT_LOCALLY
             || errnum == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE  )
         && sc->nVerifyClient == SSL_CVERIFY_OPTIONAL_NO_CA            ) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE,
+        ssl_log(s, SSL_LOG_TRACE,
                 "Certificate Verification: Verifiable Issuer is configured as "
                 "optional, therefore we're accepting the certificate");
         ok = TRUE;
@@ -741,22 +721,20 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
      * If we already know it's not ok, log the real reason
      */
     if (!ok) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR,
-                "Certificate Verification: Error (%d): %s", errnum,
-                X509_verify_cert_error_string(errnum));
-        ap_ctx_set(mc->rCtx.pConn->client->ctx, 
-                   "ssl:clientdn", NULL);
-        ap_ctx_set(mc->rCtx.pConn->client->ctx, 
-                   "ssl:verifyerror", X509_verify_cert_error_string(errnum));
+        ssl_log(s, SSL_LOG_ERROR, "Certificate Verification: Error (%d): %s",
+                errnum, X509_verify_cert_error_string(errnum));
+        ap_ctx_set(conn->client->ctx, "ssl:clientdn", NULL);
+        ap_ctx_set(conn->client->ctx, "ssl:verifyerror",
+                   X509_verify_cert_error_string(errnum));
     }
 
     /*
      * Finally check the depth of the certificate verification
      */
     if (errdepth > sc->nVerifyDepth) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR,
+        ssl_log(s, SSL_LOG_ERROR,
                 "Certificate Verification: Certificate Chain too long");
-        ap_ctx_set(mc->rCtx.pConn->client->ctx, "ssl:verifyerror", 
+        ap_ctx_set(conn->client->ctx, "ssl:verifyerror",
                    X509_verify_cert_error_string(X509_V_ERR_CERT_CHAIN_TOO_LONG));
         ok = FALSE;
     }
@@ -773,35 +751,42 @@ int ssl_callback_SSLVerify(int ok, X509_STORE_CTX *ctx)
  *  SSL_SESSION also to the inter-process disk-cache to make share it with our
  *  other Apache pre-forked server processes.
  */
-int ssl_callback_NewSessionCacheEntry(SSL *pSSL, SSL_SESSION *pNew)
+int ssl_callback_NewSessionCacheEntry(SSL *ssl, SSL_SESSION *pNew)
 {
-    SSLModConfigRec *mc = myModConfig();
+    conn_rec *conn;
+    server_rec *s;
     SSLSrvConfigRec *sc;
-    long t = 0;
+    long t;
+
+    /*
+     * Get Apache context back through SSLeay context
+     */
+    conn = (conn_rec *)SSL_get_app_data(ssl);
+    s    = conn->server;
+    sc   = mySrvConfig(s);
 
     /*
      * Set the timeout also for the internal SSLeay cache, because this way
      * our inter-process cache is consulted only when it's really necessary.
      */
-    sc = mySrvConfig(mc->rCtx.pConn->server);
-    t = SSL_get_time(pNew) + sc->nSessionCacheTimeout;
+    t = (SSL_get_time(pNew) + sc->nSessionCacheTimeout);
     SSL_set_timeout(pNew, t);
 
     /*
      * Store the SSL_SESSION in the inter-process cache with the
      * same expire time, so it expires automatically there, too.
      */
-    ssl_scache_store(pNew, t);
+    ssl_scache_store(s, pNew, t);
 
     /*
      * Log this cache operation
      */
-    ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE, 
-            "Inter-Process Session Cache: request=SET id=%s timeout=%ds (session caching)",
+    ssl_log(s, SSL_LOG_TRACE, "Inter-Process Session Cache: "
+            "request=SET id=%s timeout=%ds (session caching)",
             ssl_scache_id2sz(pNew->session_id, pNew->session_id_length),
             t-time(NULL));
 
-    /* 
+    /*
      * return 0 which means to SSLeay that the pNew is still
      * valid and was not freed by us with SSL_SESSION_free().
      */
@@ -816,26 +801,33 @@ int ssl_callback_NewSessionCacheEntry(SSL *pSSL, SSL_SESSION *pNew)
  *  of our other Apache pre-forked server processes.
  */
 SSL_SESSION *ssl_callback_GetSessionCacheEntry(
-    SSL *pSSL, unsigned char *id, int idlen, int *pCopy)
+    SSL *ssl, unsigned char *id, int idlen, int *pCopy)
 {
-    SSLModConfigRec *mc = myModConfig();
+    conn_rec *conn;
+    server_rec *s;
     SSL_SESSION *pSession;
 
+    /*
+     * Get Apache context back through SSLeay context
+     */
+    conn = (conn_rec *)SSL_get_app_data(ssl);
+    s    = conn->server;
+
     /*
      * Try to retrieve the SSL_SESSION from the inter-process cache
      */
-    pSession = ssl_scache_retrieve(id, idlen);
+    pSession = ssl_scache_retrieve(s, id, idlen);
 
     /*
      * Log this cache operation
      */
     if (pSession != NULL)
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE, 
-                "Inter-Process Session Cache: request=GET status=FOUND id=%s (session reuse)",
+        ssl_log(s, SSL_LOG_TRACE, "Inter-Process Session Cache: "
+                "request=GET status=FOUND id=%s (session reuse)",
                 ssl_scache_id2sz(id, idlen));
     else
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE, 
-                "Inter-Process Session Cache: request=GET status=MISSED id=%s (session renewal)",
+        ssl_log(s, SSL_LOG_TRACE, "Inter-Process Session Cache: "
+                "request=GET status=MISSED id=%s (session renewal)",
                 ssl_scache_id2sz(id, idlen));
 
     /*
@@ -857,19 +849,25 @@ SSL_SESSION *ssl_callback_GetSessionCacheEntry(
 void ssl_callback_DelSessionCacheEntry(
     SSL_CTX *ctx, SSL_SESSION *pSession)
 {
-    SSLModConfigRec *mc = myModConfig();
+    server_rec *s;
+
+    /*
+     * Get Apache context back through SSLeay context
+     */
+    s = (server_rec *)SSL_CTX_get_app_data(ctx);
 
     /*
      * Remove the SSL_SESSION from the inter-process cache
      */
-    ssl_scache_remove(pSession);
+    ssl_scache_remove(s, pSession);
 
     /*
      * Log this cache operation
      */
-    ssl_log(mc->rCtx.pConn->server, SSL_LOG_TRACE, 
-            "Inter-Process Session Cache: request=REM status=OK id=%s (session dead)",
-            ssl_scache_id2sz(pSession->session_id, pSession->session_id_length));
+    ssl_log(s, SSL_LOG_TRACE, "Inter-Process Session Cache: "
+            "request=REM status=OK id=%s (session dead)",
+            ssl_scache_id2sz(pSession->session_id,
+            pSession->session_id_length));
 
     return;
 }
@@ -886,7 +884,7 @@ void ssl_callback_LogTracingState(SSL *ssl, int where, int rc)
     SSLSrvConfigRec *sc;
     char *str;
 
-    /* 
+    /*
      * find corresponding server
      */
     if ((c = (conn_rec *)SSL_get_app_data(ssl)) == NULL)
@@ -895,33 +893,36 @@ void ssl_callback_LogTracingState(SSL *ssl, int where, int rc)
     if ((sc = mySrvConfig(s)) == NULL)
         return;
 
-    /* 
+    /*
      * create the various trace messages
      */
     if (sc->nLogLevel >= SSL_LOG_TRACE) {
         if (where & SSL_CB_HANDSHAKE_START)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: start");
+            ssl_log(s, SSL_LOG_TRACE, "%s: Handshake: start", SSL_LIBRARY_NAME);
         else if (where & SSL_CB_HANDSHAKE_DONE)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Handshake: done");
+            ssl_log(s, SSL_LOG_TRACE, "%s: Handshake: done", SSL_LIBRARY_NAME);
         else if (where & SSL_CB_LOOP)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Loop: %s", SSL_state_string_long(ssl));
+            ssl_log(s, SSL_LOG_TRACE, "%s: Loop: %s", 
+                    SSL_LIBRARY_NAME, SSL_state_string_long(ssl));
         else if (where & SSL_CB_READ)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Read: %s", SSL_state_string_long(ssl));
+            ssl_log(s, SSL_LOG_TRACE, "%s: Read: %s",
+                    SSL_LIBRARY_NAME, SSL_state_string_long(ssl));
         else if (where & SSL_CB_WRITE)
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Write: %s", SSL_state_string_long(ssl));
+            ssl_log(s, SSL_LOG_TRACE, "%s: Write: %s", 
+                    SSL_LIBRARY_NAME, SSL_state_string_long(ssl));
         else if (where & SSL_CB_ALERT) {
             str = (where & SSL_CB_READ) ? "read" : "write";
-            ssl_log(s, SSL_LOG_TRACE, "SSLeay: Alert: %s:%s\n",
-                    SSL_alert_type_string_long(rc), 
+            ssl_log(s, SSL_LOG_TRACE, "%s: Alert: %s:%s\n", SSL_LIBRARY_NAME,
+                    SSL_alert_type_string_long(rc),
                     SSL_alert_desc_string_long(rc));
         }
         else if (where & SSL_CB_EXIT) {
             if (rc == 0)
-                ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: failed in %s\n",
-                        SSL_state_string_long(ssl));
+                ssl_log(s, SSL_LOG_TRACE, "%s: Exit: failed in %s\n", 
+                        SSL_LIBRARY_NAME, SSL_state_string_long(ssl));
             else if (rc < 0)
-                ssl_log(s, SSL_LOG_TRACE, "SSLeay: Exit: error in %s\n",
-                        SSL_state_string_long(ssl));
+                ssl_log(s, SSL_LOG_TRACE, "%s: Exit: error in %s\n", 
+                        SSL_LIBRARY_NAME, SSL_state_string_long(ssl));
         }
     }
 
@@ -931,8 +932,8 @@ void ssl_callback_LogTracingState(SSL *ssl, int where, int rc)
      * right after a finished handshake.
      */
     if (where & SSL_CB_HANDSHAKE_DONE) {
-        ssl_log(s, SSL_LOG_INFO, 
-                "Connection: Client IP: %s, Protocol: %s, Cipher: %s (%s/%s bits)", 
+        ssl_log(s, SSL_LOG_INFO,
+                "Connection: Client IP: %s, Protocol: %s, Cipher: %s (%s/%s bits)",
                 ssl_var_lookup(NULL, s, c, NULL, "REMOTE_ADDR"),
                 ssl_var_lookup(NULL, s, c, NULL, "SSL_PROTOCOL"),
                 ssl_var_lookup(NULL, s, c, NULL, "SSL_CIPHER"),
