@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_log.c
 **  Logging Facility
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -163,7 +163,7 @@ void ssl_log(server_rec *s, int level, const char *msg, ...)
     SSLSrvConfigRec *sc;
     char *cpE;
     char *cpA;
-    
+
     /*  initialization  */
     va_start(ap, msg);
     safe_errno = errno;
@@ -210,17 +210,17 @@ void ssl_log(server_rec *s, int level, const char *msg, ...)
             lstr[i] = ' ';
         lstr[i] = NUL;
     }
-    
+
     /*  create custom message  */
     ap_vsnprintf(vstr, sizeof(vstr), msg, ap);
 
     /*  write out SSLog message  */
-    if ((add & SSL_ADD_ERRNO) && (add & SSL_ADD_SSLEAY))
-        astr = " (System and SSLeay errors follow)";
+    if ((add & SSL_ADD_ERRNO) && (add & SSL_ADD_SSLERR))
+        astr = " (System and " SSL_LIBRARY_NAME " library errors follow)";
     else if (add & SSL_ADD_ERRNO)
         astr = " (System error follows)";
-    else if (add & SSL_ADD_SSLEAY)
-        astr = " (SSLeay error follows)";
+    else if (add & SSL_ADD_SSLERR)
+        astr = " (" SSL_LIBRARY_NAME " library error follows)";
     else
         astr = "";
     if (level <= sc->nLogLevel && sc->fileLogFile != NULL) {
@@ -228,37 +228,37 @@ void ssl_log(server_rec *s, int level, const char *msg, ...)
         fprintf(sc->fileLogFile, "%s", str);
     }
     if (level & SSL_LOG_ERROR)
-        ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s, 
+        ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s,
                      "mod_ssl: %s%s", vstr, astr);
 
     /*  write out additional attachment messages  */
     if (add & SSL_ADD_ERRNO) {
         if (level <= sc->nLogLevel && sc->fileLogFile != NULL) {
-            ap_snprintf(str, sizeof(str), "%s%sSystem: %s (errno: %d)%s", 
+            ap_snprintf(str, sizeof(str), "%s%sSystem: %s (errno: %d)%s",
                         tstr, lstr, strerror(safe_errno), safe_errno, nstr);
             fprintf(sc->fileLogFile, "%s", str);
         }
         if (level & SSL_LOG_ERROR)
-            ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s, 
-                         "System: %s (errno: %d)", 
+            ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s,
+                         "System: %s (errno: %d)",
                          strerror(safe_errno), safe_errno);
     }
-    if (add & SSL_ADD_SSLEAY) {
+    if (add & SSL_ADD_SSLERR) {
         while ((e = ERR_get_error())) {
             cpE = ERR_error_string(e, NULL);
             cpA = ssl_log_annotation(cpE);
             if (level <= sc->nLogLevel && sc->fileLogFile != NULL) {
-                ap_snprintf(str, sizeof(str), "%s%sSSLeay: %s%s%s%s%s", 
-                            tstr, lstr, cpE,
-                            cpA != NULL ? " [Hint: " : "", 
+                ap_snprintf(str, sizeof(str), "%s%s%s: %s%s%s%s%s",
+                            tstr, lstr, SSL_LIBRARY_NAME, cpE,
+                            cpA != NULL ? " [Hint: " : "",
                             cpA != NULL ? cpA : "", cpA != NULL ? "]" : "",
                             nstr);
                 fprintf(sc->fileLogFile, "%s", str);
             }
             if (level & SSL_LOG_ERROR)
-                ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s, 
-                             "SSLeay: %s%s%s%s", cpE,
-                             cpA != NULL ? " [Hint: " : "", 
+                ap_log_error(APLOG_MARK, APLOG_ERR|APLOG_NOERRNO, s,
+                             "%s: %s%s%s%s", SSL_LIBRARY_NAME, cpE,
+                             cpA != NULL ? " [Hint: " : "",
                              cpA != NULL ? cpA : "", cpA != NULL ? "]" : "");
         }
     }
@@ -277,7 +277,7 @@ void ssl_die(void)
 {
     /*
      * This is used for fatal errors and here
-     * it is common module practice to really 
+     * it is common module practice to really
      * exit from the complete program.
      */
     exit(1);
