@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_pphrase.c
 **  Pass Phrase Dialog
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -59,8 +59,8 @@
  * ====================================================================
  */
                              /* ``Treat your password like your
-                                  toothbrush. Don't let anybody 
-                                  else use it, and get a new one 
+                                  toothbrush. Don't let anybody
+                                  else use it, and get a new one
                                   every six months.''
                                            -- Clifford Stoll     */
 #include "mod_ssl.h"
@@ -79,7 +79,7 @@
 void ssl_pphrase_Handle(server_rec *s, pool *p)
 {
     SSLModConfigRec *mc = myModConfig();
-    SSLSrvConfigRec *pSrvConfig;
+    SSLSrvConfigRec *sc;
     server_rec *pServ;
     char *cpServerName;
     char szPath[MAX_STRING_LEN];
@@ -110,9 +110,9 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
      * Walk through all configured servers
      */
     for (pServ = s; pServ != NULL; pServ = pServ->next) {
-        pSrvConfig = mySrvConfig(pServ);
+        sc = mySrvConfig(pServ);
 
-        if (!pSrvConfig->bEnabled)
+        if (!sc->bEnabled)
             continue;
 
         cpServerName = ap_psprintf(p, "%s:%d", pServ->server_hostname, pServ->port);
@@ -122,21 +122,21 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * Read in server certificate: This is the easy part
          * because this file isn't encrypted in any way.
          */
-        if (pSrvConfig->szCertificateFile == NULL) {
-            ssl_log(pServ, SSL_LOG_ERROR, 
+        if (sc->szCertificateFile == NULL) {
+            ssl_log(pServ, SSL_LOG_ERROR,
                     "Init: Server %s should be SSL-aware but has no certificate configured "
                     "[Hint: SSLCertifcateFile]", cpServerName);
             ssl_die();
         }
-        ap_cpystrn(szPath, pSrvConfig->szCertificateFile, sizeof(szPath));     
+        ap_cpystrn(szPath, sc->szCertificateFile, sizeof(szPath));
         if ((fp = ap_pfopen(p, szPath, "r")) == NULL) {
-            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO, 
+            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                     "Init: Can't open server certificate file %s", szPath);
             ssl_die();
         }
         pX509Cert = X509_new();
         if (!PEM_read_X509(fp, &pX509Cert, NULL)) {
-            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLEAY, 
+            ssl_log(s, SSL_LOG_ERROR|SSL_ADD_SSLERR,
                     "Init: Unable to read server certificate from file %s", szPath);
             ssl_die();
         }
@@ -159,8 +159,8 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * from a dialog program). The important point here is that ISPs
          * usually have hundrets of virtual servers configured and a lot of
          * them use SSL, so really we have to minimize the pass phrase
-         * dialogs. 
-         * 
+         * dialogs.
+         *
          * The idea is this: When N virtual hosts are configured and all of
          * them use encrypted private keys with different pass phrases, we
          * have no chance and have to pop up N pass phrase dialogs. But
@@ -169,10 +169,10 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * phrase for all). When this is the case we can minimize the dialogs
          * by trying to re-use already known/entered pass phrases.
          */
-        if (pSrvConfig->szKeyFile)
-            ap_cpystrn(szPath, pSrvConfig->szKeyFile, sizeof(szPath));     
+        if (sc->szKeyFile)
+            ap_cpystrn(szPath, sc->szKeyFile, sizeof(szPath));
 
-        /* 
+        /*
          * Spread context variables for callback function
          */
         myCtxVarSet(mc, 1, pServ);
@@ -192,13 +192,13 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
         bPassPhraseDialogOnce = TRUE;
 
         for (;;) {
-            /* 
+            /*
              * Try to read the private key file with the help of
              * the callback function which serves the pass
              * phrases to SSLeay
              */
             if ((fp = ap_pfopen(p, szPath, "r")) == NULL) {
-                ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO, 
+                ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                         "Init: Can't open server private key file %s", szPath);
                 ssl_die();
             }
@@ -207,15 +207,15 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
                          ssl_pphrase_Handle_CB) ? TRUE : FALSE);
             ap_pfclose(p, fp);
 
-            /* 
-             * when the private key file now was readable, 
+            /*
+             * when the private key file now was readable,
              * it's fine and we go out of the loop
              */
             if (bReadable)
                break;
 
-            /* 
-             * when we have more remembered pass phrases 
+            /*
+             * when we have more remembered pass phrases
              * try to reuse these first.
              */
             if (nPassPhraseCur < nPassPhrase) {
@@ -223,7 +223,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
                 continue;
             }
 
-            /* 
+            /*
              * else it's not readable and we have no more
              * remembered pass phrases. Then this has to mean
              * that the callback function popped up the dialog
@@ -231,11 +231,11 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
              * user (but not the dialog program) a few more
              * chances...
              */
-            if (   pSrvConfig->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN
-                && cpPassPhraseCur != NULL 
+            if (   sc->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN
+                && cpPassPhraseCur != NULL
                 && nPassPhraseRetry < BUILTIN_DIALOG_RETRIES ) {
                 fprintf(stdout, "Apache:mod_ssl:Error: Pass phrase incorrect "
-                        "(%d more retr%s permitted).\n", 
+                        "(%d more retr%s permitted).\n",
                         (BUILTIN_DIALOG_RETRIES-nPassPhraseRetry),
                         (BUILTIN_DIALOG_RETRIES-nPassPhraseRetry) == 1 ? "y" : "ies");
                 nPassPhraseRetry++;
@@ -247,7 +247,7 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
             /*
              * Ok, anything else now means a fatal error.
              */
-            if (pSrvConfig->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
+            if (sc->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
                 fprintf(stdout, "Apache:mod_ssl:Error: Pass phrase incorrect.\n");
                 fprintf(stdout, "**Stopped\n");
             }
@@ -259,17 +259,17 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
          * Log the type of reading
          */
         if (nPassPhraseDialogCur == 0)
-            ssl_log(pServ, SSL_LOG_TRACE, 
-                    "Init: (%s) unencrypted private key - pass phrase not required", 
+            ssl_log(pServ, SSL_LOG_TRACE,
+                    "Init: (%s) unencrypted private key - pass phrase not required",
                     cpServerName);
         else {
             if (cpPassPhraseCur != NULL)
-                ssl_log(pServ, SSL_LOG_TRACE, 
-                        "Init: (%s) encrypted private key - pass phrase requested", 
+                ssl_log(pServ, SSL_LOG_TRACE,
+                        "Init: (%s) encrypted private key - pass phrase requested",
                         cpServerName);
             else
-                ssl_log(pServ, SSL_LOG_TRACE, 
-                        "Init: (%s) encrypted private key - pass phrase reused", 
+                ssl_log(pServ, SSL_LOG_TRACE,
+                        "Init: (%s) encrypted private key - pass phrase reused",
                         cpServerName);
         }
 
@@ -293,11 +293,11 @@ void ssl_pphrase_Handle(server_rec *s, pool *p)
      * Let the user know when we're successful.
      */
     if (nPassPhraseDialog > 0) {
-        pSrvConfig = mySrvConfig(s);
-        if (pSrvConfig->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
+        sc = mySrvConfig(s);
+        if (sc->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
             fprintf(stdout, "\n");
             fprintf(stdout, "Ok: Pass Phrase Dialog successful.\n");
-        }    
+        }
     }
 
     /*
@@ -319,7 +319,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     server_rec *s;
     pool *p;
     ssl_ds_array *aPassPhrase;
-    SSLSrvConfigRec *pSrvConfig;
+    SSLSrvConfigRec *sc;
     int *pnPassPhraseCur;
     char **cppPassPhraseCur;
     char *cpServerName;
@@ -328,7 +328,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     BOOL *pbPassPhraseDialogOnce;
     char **cpp;
     int len = -1;
-    
+
     /*
      * Reconnect to the context of ssl_phrase_Handle()
      */
@@ -341,7 +341,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     pnPassPhraseDialog     = myCtxVarGet(mc, 7, int *);
     pnPassPhraseDialogCur  = myCtxVarGet(mc, 8, int *);
     pbPassPhraseDialogOnce = myCtxVarGet(mc, 9, BOOL *);
-    pSrvConfig             = mySrvConfig(s);
+    sc                     = mySrvConfig(s);
 
     (*pnPassPhraseDialog)++;
     (*pnPassPhraseDialogCur)++;
@@ -358,14 +358,14 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     /*
      * Builtin dialog
      */
-    if (pSrvConfig->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
+    if (sc->nPassPhraseDialogType == SSL_PPTYPE_BUILTIN) {
         char *prompt;
         int i;
 
-        ssl_log(s, SSL_LOG_INFO, 
+        ssl_log(s, SSL_LOG_INFO,
                 "Init: Requesting pass phrase via builtin terminal dialog");
 
-        /* 
+        /*
          * Reconnect STDERR to terminal (here STDOUT) because
          * at our init stage Apache already connected STDERR
          * to the general error logfile.
@@ -391,7 +391,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
             fprintf(stderr, "Server %s\n", cpServerName);
         }
 
-        /* 
+        /*
          * Emulate the SSLeay internal pass phrase dialog
          * (see crypto/pem/pem_lib.c:def_callback() for details)
          */
@@ -401,7 +401,7 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
                 PEMerr(PEM_F_DEF_CALLBACK,PEM_R_PROBLEMS_GETTING_PASSWORD);
                 memset(buf, 0, (unsigned int)bufsize);
                 return (-1);
-            } 
+            }
             len = strlen(buf);
             if (len < 4)
                 fprintf(stderr, "Apache:mod_ssl:Error: Pass phrase too short (needs to be at least 4 chars).\n");
@@ -418,15 +418,15 @@ int ssl_pphrase_Handle_CB(char *buf, int bufsize, int w)
     /*
      * Filter program
      */
-    else if (pSrvConfig->nPassPhraseDialogType == SSL_PPTYPE_FILTER) {
+    else if (sc->nPassPhraseDialogType == SSL_PPTYPE_FILTER) {
         char *cmd;
         char *result;
 
-        ssl_log(s, SSL_LOG_INFO, 
+        ssl_log(s, SSL_LOG_INFO,
                 "Init: Requesting pass phrase from dialog filter program (%s)",
-                pSrvConfig->szPassPhraseDialogPath);
+                sc->szPassPhraseDialogPath);
 
-        cmd = ap_psprintf(p, "%s %s", pSrvConfig->szPassPhraseDialogPath, cpServerName);
+        cmd = ap_psprintf(p, "%s %s", sc->szPassPhraseDialogPath, cpServerName);
         result = ssl_util_readfilter(s, p, cmd);
         ap_cpystrn(buf, result, bufsize);
         len = strlen(buf);
