@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_scache.c
 **  Session Cache
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -72,7 +72,7 @@
 **  _________________________________________________________________
 */
 
-/*  
+/*
  *  FIXME: There is no define in SSLeay, but SSLeay uses 1024*10,
  *  so 1024*20 should be ok.
  */
@@ -84,11 +84,11 @@ void ssl_scache_init(server_rec *s, pool *p)
 
     if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
         ssl_scache_dbm_init(s, p);
-    ssl_scache_expire();
+    ssl_scache_expire(s);
     return;
 }
 
-void ssl_scache_store(SSL_SESSION *pSession, int timeout)
+void ssl_scache_store(server_rec *s, SSL_SESSION *pSession, int timeout)
 {
     SSLModConfigRec *mc = myModConfig();
     SessionCacheInfo SCI;
@@ -106,12 +106,12 @@ void ssl_scache_store(SSL_SESSION *pSession, int timeout)
 
     /* and store it... */
     if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
-        ssl_scache_dbm_store(&SCI);
+        ssl_scache_dbm_store(s, &SCI);
 
     return;
 }
 
-SSL_SESSION *ssl_scache_retrieve(UCHAR *id, int idlen)
+SSL_SESSION *ssl_scache_retrieve(server_rec *s, UCHAR *id, int idlen)
 {
     SSLModConfigRec *mc = myModConfig();
     SSL_SESSION *pSession = NULL;
@@ -127,7 +127,7 @@ SSL_SESSION *ssl_scache_retrieve(UCHAR *id, int idlen)
 
     /* perform cache query */
     if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
-        ssl_scache_dbm_retrieve(&SCI);
+        ssl_scache_dbm_retrieve(s, &SCI);
 
     /* return immediately if not found */
     if (SCI.ucaData == NULL)
@@ -137,7 +137,7 @@ SSL_SESSION *ssl_scache_retrieve(UCHAR *id, int idlen)
     tNow = time(NULL);
     if (SCI.tExpiresAt <= tNow) {
         if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
-            ssl_scache_dbm_remove(&SCI);
+            ssl_scache_dbm_remove(s, &SCI);
         return NULL;
     }
 
@@ -146,7 +146,7 @@ SSL_SESSION *ssl_scache_retrieve(UCHAR *id, int idlen)
     return pSession;
 }
 
-void ssl_scache_remove(SSL_SESSION *pSession)
+void ssl_scache_remove(server_rec *s, SSL_SESSION *pSession)
 {
     SSLModConfigRec *mc = myModConfig();
     SessionCacheInfo SCI;
@@ -160,17 +160,17 @@ void ssl_scache_remove(SSL_SESSION *pSession)
 
     /* perform remove */
     if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
-        ssl_scache_dbm_remove(&SCI);
+        ssl_scache_dbm_remove(s, &SCI);
 
     return;
 }
 
-void ssl_scache_expire(void)
+void ssl_scache_expire(server_rec *s)
 {
     SSLModConfigRec *mc = myModConfig();
 
     if (mc->nSessionCacheMode == SSL_SCMODE_DBM)
-        ssl_scache_dbm_expire();
+        ssl_scache_dbm_expire(s);
     return;
 }
 
@@ -214,7 +214,7 @@ void ssl_scache_dbm_init(server_rec *s, pool *p)
      * _can_ be created.
      */
     ssl_mutex_on();
-    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile, 
+    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile,
                             O_RDWR|O_CREAT, SSL_DBM_FILE_MODE)) == NULL) {
         ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                 "Cannot create SSLSessionCache DBM file `%s'",
@@ -225,17 +225,17 @@ void ssl_scache_dbm_init(server_rec *s, pool *p)
     ssl_dbm_close(dbm);
 
 #ifndef WIN32
-    /* 
-     * we have to make sure the Apache child processes 
+    /*
+     * we have to make sure the Apache child processes
      * have access to the DBM file...
      */
     if (geteuid() == 0 /* is superuser */) {
-        chown(mc->szSessionCacheDataFile, 
+        chown(mc->szSessionCacheDataFile,
               ap_user_id, -1 /* no gid change */);
-        chown(ap_pstrcat(p, mc->szSessionCacheDataFile, 
+        chown(ap_pstrcat(p, mc->szSessionCacheDataFile,
                          SSL_DBM_FILE_SUFFIX_DIR, NULL),
               ap_user_id, -1 /* no gid change */);
-        chown(ap_pstrcat(p, mc->szSessionCacheDataFile, 
+        chown(ap_pstrcat(p, mc->szSessionCacheDataFile,
                          SSL_DBM_FILE_SUFFIX_PAG, NULL),
               ap_user_id, -1 /* no gid change */);
     }
@@ -245,7 +245,7 @@ void ssl_scache_dbm_init(server_rec *s, pool *p)
     return;
 }
 
-void ssl_scache_dbm_store(SessionCacheInfo *SCI)
+void ssl_scache_dbm_store(server_rec *s, SessionCacheInfo *SCI)
 {
     SSLModConfigRec *mc = myModConfig();
     DBM *dbm;
@@ -264,9 +264,9 @@ void ssl_scache_dbm_store(SessionCacheInfo *SCI)
 
     /* and store it to the DBM file */
     ssl_mutex_on();
-    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile, 
+    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile,
                             O_RDWR, SSL_DBM_FILE_MODE)) == NULL) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR|SSL_ADD_ERRNO,
+        ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                 "Cannot open SSLSessionCache DBM file `%s' for writing (store)",
                 mc->szSessionCacheDataFile);
         ssl_mutex_off();
@@ -282,7 +282,7 @@ void ssl_scache_dbm_store(SessionCacheInfo *SCI)
     return;
 }
 
-void ssl_scache_dbm_retrieve(SessionCacheInfo *SCI)
+void ssl_scache_dbm_retrieve(server_rec *s, SessionCacheInfo *SCI)
 {
     SSLModConfigRec *mc = myModConfig();
     DBM *dbm;
@@ -300,9 +300,9 @@ void ssl_scache_dbm_retrieve(SessionCacheInfo *SCI)
 
     /* and fetch it from the DBM file */
     ssl_mutex_on();
-    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile, 
+    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile,
                             O_RDONLY, SSL_DBM_FILE_MODE)) == NULL) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR|SSL_ADD_ERRNO,
+        ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                 "Cannot open SSLSessionCache DBM file `%s' for reading (fetch)",
                 mc->szSessionCacheDataFile);
         ssl_mutex_off();
@@ -319,14 +319,14 @@ void ssl_scache_dbm_retrieve(SessionCacheInfo *SCI)
     /* copy over the information to the SCI */
     SCI->nData   = dbmval.dsize-sizeof(SCI->tExpiresAt);
     SCI->ucaData = (UCHAR *)malloc(dbmval.dsize-sizeof(SCI->tExpiresAt));
-    memcpy(SCI->ucaData, (char *)dbmval.dptr+sizeof(SCI->tExpiresAt), 
+    memcpy(SCI->ucaData, (char *)dbmval.dptr+sizeof(SCI->tExpiresAt),
            dbmval.dsize-sizeof(SCI->tExpiresAt));
     memcpy(&SCI->tExpiresAt, dbmval.dptr, sizeof(SCI->tExpiresAt));
 
     return;
 }
 
-void ssl_scache_dbm_remove(SessionCacheInfo *SCI)
+void ssl_scache_dbm_remove(server_rec *s, SessionCacheInfo *SCI)
 {
     SSLModConfigRec *mc = myModConfig();
     DBM *dbm;
@@ -338,9 +338,9 @@ void ssl_scache_dbm_remove(SessionCacheInfo *SCI)
 
     /* and delete it from the DBM file */
     ssl_mutex_on();
-    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile, 
+    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile,
                             O_RDWR, SSL_DBM_FILE_MODE)) == NULL) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR|SSL_ADD_ERRNO,
+        ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                 "Cannot open SSLSessionCache DBM file `%s' for writing (delete)",
                 mc->szSessionCacheDataFile);
         ssl_mutex_off();
@@ -353,7 +353,7 @@ void ssl_scache_dbm_remove(SessionCacheInfo *SCI)
     return;
 }
 
-void ssl_scache_dbm_expire(void)
+void ssl_scache_dbm_expire(server_rec *s)
 {
     SSLModConfigRec *mc = myModConfig();
     static int nExpireCalls = 0;
@@ -373,9 +373,9 @@ void ssl_scache_dbm_expire(void)
         nExpireCalls = 0;
 
     ssl_mutex_on();
-    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile, 
+    if ((dbm = ssl_dbm_open(mc->szSessionCacheDataFile,
                             O_RDWR, SSL_DBM_FILE_MODE)) == NULL) {
-        ssl_log(mc->rCtx.pConn->server, SSL_LOG_ERROR|SSL_ADD_ERRNO,
+        ssl_log(s, SSL_LOG_ERROR|SSL_ADD_ERRNO,
                 "Cannot open SSLSessionCache DBM file `%s' for expiring",
                 mc->szSessionCacheDataFile);
         ssl_mutex_off();
