@@ -1,9 +1,9 @@
-/*                      _             _ 
-**  _ __ ___   ___   __| |    ___ ___| |  
-** | '_ ` _ \ / _ \ / _` |   / __/ __| |  
+/*                      _             _
+**  _ __ ___   ___   __| |    ___ ___| |
+** | '_ ` _ \ / _ \ / _` |   / __/ __| |
 ** | | | | | | (_) | (_| |   \__ \__ \ | mod_ssl - Apache Interface to SSLeay
 ** |_| |_| |_|\___/ \__,_|___|___/___/_| http://www.engelschall.com/sw/mod_ssl/
-**                      |_____|         
+**                      |_____|
 **  ssl_engine_vars.c
 **  Variable Lookup Facility
 */
@@ -16,7 +16,7 @@
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following
@@ -25,7 +25,7 @@
  *
  * 3. All advertising materials mentioning features or use of this
  *    software must display the following acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -40,7 +40,7 @@
  *
  * 6. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
- *    "This product includes software developed by 
+ *    "This product includes software developed by
  *     Ralf S. Engelschall <rse@engelschall.com> for use in the
  *     mod_ssl project (http://www.engelschall.com/sw/mod_ssl/)."
  *
@@ -59,7 +59,7 @@
  * ====================================================================
  */
                              /* ``Those of you who think they
-                                  know everything are very annoying 
+                                  know everything are very annoying
                                   to those of us who do.''
                                                   -- Unknown       */
 #include "mod_ssl.h"
@@ -85,9 +85,9 @@ static char *ssl_var_lookup_ssl_version(pool *p, char *var);
 
 void ssl_var_register(void)
 {
-    ap_hook_configure("ap::mod_ssl::var_lookup", 
+    ap_hook_configure("ap::mod_ssl::var_lookup",
                       AP_HOOK_SIG6(ptr,ptr,ptr,ptr,ptr,ptr), AP_HOOK_DECLINE(NULL));
-    ap_hook_register("ap::mod_ssl::var_lookup", 
+    ap_hook_register("ap::mod_ssl::var_lookup",
                      ssl_var_lookup, AP_HOOK_NOCTX);
     return;
 }
@@ -107,15 +107,15 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
      * When no pool is given try to find one
      */
     if (p == NULL) {
-        if (r != NULL) 
+        if (r != NULL)
             p = r->pool;
-        else if (c != NULL) 
+        else if (c != NULL)
             p = c->pool;
-        else 
+        else
             p = mc->pPool;
     }
 
-    /* 
+    /*
      * Request dependent stuff
      */
     if (r != NULL) {
@@ -150,7 +150,7 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
         else if (strcEQ(var, "QUERY_STRING"))
             result = r->args;
         else if (strcEQ(var, "REMOTE_HOST"))
-            result = (char *)ap_get_remote_host(r->connection, 
+            result = (char *)ap_get_remote_host(r->connection,
                                                 r->per_dir_config, REMOTE_NAME);
         else if (strcEQ(var, "REMOTE_IDENT"))
             result = (char *)ap_get_remote_logname(r);
@@ -168,8 +168,8 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
             result = r->protocol;
     }
 
-    /* 
-     * Connection stuff 
+    /*
+     * Connection stuff
      */
     if (result == NULL && c != NULL) {
         if (strcEQ(var, "REMOTE_ADDR"))
@@ -198,7 +198,7 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
             tc = time(NULL);
             tm = localtime(&tc);
             result = ap_psprintf(p, "%02d%02d",
-                        (tm->tm_year / 100) + 19, tm->tm_year % 100);
+                                 (tm->tm_year / 100) + 19, tm->tm_year % 100);
             resdup = FALSE;
         }
 #define MKTIMESTR(format, tmfield) \
@@ -227,7 +227,7 @@ char *ssl_var_lookup(pool *p, server_rec *s, conn_rec *c, request_rec *r, char *
         else if (strcEQ(var, "TIME")) {
             tc = time(NULL);
             tm = localtime(&tc);
-            result = ap_psprintf(p, 
+            result = ap_psprintf(p,
                         "%02d%02d%02d%02d%02d%02d%02d", (tm->tm_year / 100) + 19,
                         (tm->tm_year % 100), tm->tm_mon+1, tm->tm_mday,
                         tm->tm_hour, tm->tm_min, tm->tm_sec);
@@ -311,7 +311,7 @@ static char *ssl_var_lookup_ssl_cert(pool *p, X509 *xs, char *var)
     X509_NAME *xsname;
     int nid;
     char *cp;
-    
+
     result = NULL;
     resdup = TRUE;
 
@@ -390,7 +390,7 @@ static char *ssl_var_lookup_ssl_cert_dn(pool *p, X509_NAME *xsname, char *var)
     char *result;
     X509_NAME_ENTRY *xsne;
     int i, j, n;
-    
+
     result = NULL;
 
     for (i = 0; ssl_var_lookup_ssl_cert_dn_rec[i].name != NULL; i++) {
@@ -417,7 +417,7 @@ static char *ssl_var_lookup_ssl_cert_valid(pool *p, ASN1_UTCTIME *tm)
     BIO* bio;
     int n;
 
-    if ((bio = BIO_new(BIO_s_mem())) == NULL) 
+    if ((bio = BIO_new(BIO_s_mem())) == NULL)
         return NULL;
     ASN1_UTCTIME_print(bio, tm);
     n = BIO_pending(bio);
@@ -434,7 +434,7 @@ static char *ssl_var_lookup_ssl_cert_serial(pool *p, X509 *xs)
     BIO* bio;
     int n;
 
-    if ((bio = BIO_new(BIO_s_mem())) == NULL) 
+    if ((bio = BIO_new(BIO_s_mem())) == NULL)
         return NULL;
     i2a_ASN1_INTEGER(bio, X509_get_serialNumber(xs));
     n = BIO_pending(bio);
@@ -470,7 +470,7 @@ static char *ssl_var_lookup_ssl_cert_PEM(pool *p, X509 *xs)
     BIO *bio;
     int n;
 
-    if ((bio = BIO_new(BIO_s_mem())) == NULL) 
+    if ((bio = BIO_new(BIO_s_mem())) == NULL)
         return NULL;
     PEM_write_bio_X509(bio, xs);
     n = BIO_pending(bio);
@@ -532,9 +532,9 @@ static const struct {
     int nUseKeySize;
     int nAlgKeySize;
 } ssl_var_lookup_ssl_cipher_bits_rec[] = {
-#if SSLEAY_VERSION_NUMBER >= 0x0900
+#if (SSL_LIBRARY_VERSION >= 0x0900)
     { SSL3_TXT_RSA_IDEA_128_SHA          /*IDEA-CBC-SHA*/,           128, 128 },
-#endif                                                                            
+#endif
     { SSL3_TXT_RSA_NULL_MD5              /*NULL-MD5*/,                 0,   0 },
     { SSL3_TXT_RSA_NULL_SHA              /*NULL-SHA*/,                 0,   0 },
     { SSL3_TXT_RSA_RC4_40_MD5            /*EXP-RC4-MD5*/,             40, 128 },
@@ -608,14 +608,12 @@ static char *ssl_var_lookup_ssl_version(pool *p, char *var)
         result = ap_psprintf(p, "mod_ssl/%s", MOD_SSL_VERSION);
     }
     else if (strEQ(var, "LIBRARY")) {
-        result = ap_palloc(p, 50);
-        cp = SSLeay_version(SSLEAY_VERSION);
-        for ( ; !isdigit(*cp); cp++)
-            ;
-        ap_cpystrn(result, "SSLeay/", 50);
-        for (cp2 = result+strlen(result); *cp != ' ' && *cp != NUL; )
-            *cp2++ = *cp++;
-        *cp2 = NUL;
+        result = ap_pstrdup(p, SSLeay_version(SSLEAY_VERSION));
+        if ((cp = index(result, ' ')) != NULL) {
+            *cp = '/';
+            if ((cp2 = index(cp, ' ')) != NULL)
+                *cp2 = NUL;
+        }
     }
     return result;
 }
